<?php

namespace Drupal\password_notification\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Delete Password Changed History.
 */
class PasswordChangedHistoryDeleteForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'password_changed_history_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $arg1 = NULL) {
    $total_records = 'No Result.';
    $record_exist = FALSE;

    // Get Records Count.
    $db = \Drupal::database();
    $get_result_count = $db->select('password_changed_history', 'p')
      ->fields('p', ['id'])
      ->countQuery()
      ->execute()
      ->fetchField();
    if ($get_result_count) {
      $total_records = 'Total Records: ' . $get_result_count;
      $record_exist = TRUE;
    }
    $form['records_count'] = [
      '#markup' => '<div>' . $total_records . '</div>',
    ];
    if ($record_exist == TRUE) {
      $form['submit'] = [
        '#type' => 'submit',
        '#value' => t('Delete Records'),
      ];
      $form['help_text'] = [
        '#markup' => '<div>Note: By Default Delete Records Limit is 1000. To Update Limit go to  and Update the Limit.</div>',
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::config('password_notification.settings');
    $limit = $config->get('delete_records_limit');

    $db = \Drupal::database();
    $query = $db->select('password_changed_history', 'p');
    $query->fields('p', ['id']);
    $query->range(0, $limit);
    $query->orderBy('p.created', 'ASC');
    $ids = $query->execute()->fetchCol();
    foreach ($ids as $result) {
      $operations[] = [
        [$this->batchFunction($result), []],
      ];
    }
    $batch = [
      'title' => t('Batch Operation'),
      'operations' => $operations,
      'init_message' => t('Batch Operation starting...'),
      'progress_message' => t('Processed @current out of @total.'),
      'error_message' => t('Fix has encountered an error.'),
      'finished' => $this->finishedCallback(),
    ];
    batch_set($batch);
  }

  /**
   * Batch Operation Callback.
   */
  public function batchFunction($id) {
    $db = \Drupal::database();
    $db->delete('password_changed_history')
      ->condition('id', $id, '=')
      ->execute();
  }

  /**
   * Batch Operation Finished Callback..
   */
  public function finishedCallback() {
    drupal_set_message('Delete Process Completed.');
  }

}
