<?php

namespace Drupal\password_notification\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\UserInterface;

/**
 * Password Changed history page.
 */
class PasswordChangedHistoryForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'password_changed_history_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, UserInterface $user = NULL) {
    $form = [];
    $date_format = 'The date format should be DD-MM-YYYY and Example Format is ' . date('d-m-Y');
    $open = FALSE;
    $username = $email = $start_date = $end_date = '';
    $date_format = 'The date format should be DD-MM-YYYY and Example Format is ' . date('d-m-Y');
    // Configure the table header columns.
    $header = [
    ['data' => 'Name', 'field' => 'username'],
    ['data' => 'Email', 'field' => 'email'],
    ['data' => 'User Id', 'field' => 'user_id'],
    ['data' => 'Changed by(User Id)', 'field' => 'changed_by_user_id'],
    ['data' => 'Changed by(Name)', 'field' => 'changed_by_user_name'],
    ['data' => 'IP Address', 'field' => 'ip_address'],
    ['data' => 'Mail Sent', 'field' => 'mail_send'],
    ['data' => 'Date', 'field' => 'created', 'sort' => 'desc'],
    ];
    // Select Query from Password Changed History Table.
    $db = \Drupal::database();
    $query = $db->select('password_changed_history', 'p')
      ->extend('Drupal\Core\Database\Query\TableSortExtender')
      ->extend('Drupal\Core\Database\Query\PagerSelectExtender');
    if (is_object($user)) {
      $query->condition('p.user_id', $user->get('uid')->get(0)->getValue()['value'], '=');
    }
    // Filter by Username.
    if (!empty($_GET['username'])) {
      $username = $_GET['username'];
      $query->condition('p.username', '%' . db_like($_GET['username']) . '%', 'LIKE');
    }
    // Filter by Email.
    if (!empty($_GET['email'])) {
      $email = $_GET['email'];
      $query->condition('p.email', $_GET['email'], '=');
    }
    if (!empty($_GET['start_date']) && !empty($_GET['end_date'])) {
      $start_date = $_GET['start_date'];
      $start_date_timestamp = strtotime($start_date . '00:00:00');
      $end_date = $_GET['end_date'];
      $end_date_timestamp = strtotime($end_date . '23:59:59');
      $query->condition('p.created', [$start_date_timestamp, $end_date_timestamp], 'BETWEEN');
    }
    $query->fields('p', ['username',
      'email',
      'user_id',
      'changed_by_user_id',
      'changed_by_user_name',
      'ip_address',
      'mail_send',
      'created',
    ])
      ->limit(10)
      ->orderByHeader($header);

    $results = $query->execute();
    if (!empty($results)) {
      $rows = [];
      foreach ($results as $row) {
        $rows[] = [$row->username,
          $row->email,
          $row->user_id,
          $row->changed_by_user_id,
          $row->changed_by_user_name,
          $row->ip_address,
          $row->mail_send,
          date('d-m-Y h:i A', $row->created),
        ];
      }
      /* Filters Code Start */
      if (!empty($_GET['username']) || !empty($_GET['email']) || !empty($_GET['start_date']) || !empty($_GET['end_date'])) {
        $open = TRUE;
      }
      $form['filter'] = [
        '#type' => 'details',
        '#title' => $this->t('Filter option'),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
        '#open' => $open,
      ];
      if (!$user) {
        $form['filter']['username'] = [
          '#type' => 'textfield',
          '#title' => $this->t('Username'),
          '#default_value' => $username,
          '#size' => 20,
        ];
        $form['filter']['email'] = [
          '#type' => 'textfield',
          '#title' => $this->t('Email'),
          '#default_value' => $email,
          '#size' => 20,
        ];
      }
      $form['filter']['start_date'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Start Date'),
        '#description' => $date_format,
        '#default_value' => $start_date,
        '#size' => 20,
      ];
      $form['filter']['end_date'] = [
        '#type' => 'textfield',
        '#title' => $this->t('End Date'),
        '#description' => $date_format,
        '#default_value' => $end_date,
        '#size' => 20,
      ];
      $form['filter']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Apply'),
      ];
      $form['filter']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#submit' =>
      [[$this, 'reseFormSubmit']],
        '#limit_validation_errors' => [],
      ];
      /* Filters Code end */
      $form['table'] = [
        '#theme' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#empty' => $this->t('No Password Changed history available.'),
      ];
      $form['pager'] = ['#type' => 'pager'];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Email Validation.
    if (!empty($form_state->getValue('email'))) {
      if (!valid_email_address($form_state->getValue('email'))) {
        form_set_error('email', 'Please Provide Valid Email Address.');
      }
    }
    /* Date Filter Validation Code Start */
    // Start Date Validation.
    if (!empty($form_state->getValue('end_date'))) {
      if (!$form_state->getValue('start_date')) {
        $form_state->setErrorByName('start_date', $this->t('Please Provide Start Date.'));
      }
    }
    // End Date Validation.
    if (!empty($form_state->getValue('start_date'))) {
      if (!$form_state->getValue('end_date')) {
        $form_state->setErrorByName('end_date', $this->t('Please Provide End Date.'));
      }
    }
    /* Date Filter Validation Code End */
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $username = $email = $start_date = $end_date = '';
    // Username.
    if (!empty($form_state->getValue('username'))) {
      $username = $form_state->getValue('username');
    }
    // Email.
    if (!empty($form_state->getValue('email'))) {
      $email = $form_state->getValue('email');
    }
    // Start date.
    if (!empty($form_state->getValue('start_date'))) {
      $start_date = $form_state->getValue('start_date');
    }
    // End date.
    if (!empty($form_state->getValue('end_date'))) {
      $end_date = $form_state->getValue('end_date');
    }
    $get_route_name = \Drupal::routeMatch()->getRouteName();
    $route_param = [];
    $query_param = [];
    switch ($get_route_name) {
      case 'password_notification.report':
        if (!empty($username) || !empty($email) || !empty($start_date) || !empty($end_date)) {
          $query_param = [
            'query' => [
              'username' => $username,
              'email' => $email,
              'start_date' => $start_date,
              'end_date' => $end_date,
            ],
          ];
        }
        break;

      case 'password_notification.user_report':
        $get_current_path = \Drupal::request()->getpathInfo();
        $args = explode('/', $get_current_path);
        $route_param = ['user' => $args[2]];
        if (!empty($start_date) && !empty($end_date)) {
          $query_param = [
            'query' => [
              'start_date' => $start_date,
              'end_date' => $end_date,
            ],
          ];
        }
        break;
    }
    $form_state->setRedirect($get_route_name,
    $route_param,
    $query_param
    );
  }

  /**
   * {@inheritdoc}
   */
  public function reseFormSubmit(array &$form, FormStateInterface $form_state) {
    $get_route_name = \Drupal::routeMatch()->getRouteName();
    $route_param = [];
    if ($get_route_name == 'password_notification.user_report') {
      $get_current_path = \Drupal::request()->getpathInfo();
      $args = explode('/', $get_current_path);
      $route_param = ['user' => $args[2]];
    }
    $form_state->setRedirect($get_route_name, $route_param);
  }

}
