<?php

namespace Drupal\password_notification\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures Password Notification settings.
 */
class PasswordNotificationConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'password_notification.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'password_notification_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('password_notification.settings');
    $form['password_notification_mail'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Password Notification Email'),
      '#description' => $this->t('Set whether Password Notification Email is active or not.'),
      '#default_value' => $config->get('password_notification_mail'),
    ];
    $form['password_notification_log'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Log History'),
      '#description' => $this->t('Set whether Password Notification Logs Entry is active or not.'),
      '#default_value' => $config->get('password_notification_log'),
    ];
    $form['password_notification_fieldset'] = [
      '#type' => 'details',
      '#title' => $this->t('Password Notification Mail Content'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#open' => TRUE,
    ];
    $form['password_notification_fieldset']['mail_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#description' => $this->t("The mail's subject."),
      '#required' => TRUE,
      '#default_value' => $config->get('mail_subject'),
    ];
    $form['password_notification_fieldset']['mail_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message'),
      '#description' => $this->t("The mail's message body.<br/> Available Tokens: [user-name], [current-user-name], [site-url], [site-name]"),
      '#required' => TRUE,
      '#default_value' => $config->get('mail_body'),
    ];
    $form['password_notification_fieldset']['mail_bcc'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Bcc'),
      '#description' => $this->t('Please Provide Bcc with comma separated.<br/> Example: user1@test.com,user2@test.com'),
      '#default_value' => $config->get('mail_bcc'),
    ];
    $form['password_notification_fieldset']['mail_cc'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Cc'),
      '#description' => $this->t('Please Provide Cc with comma separated.<br/> Example: user1@test.com,user2@test.com'),
      '#default_value' => $config->get('mail_cc'),
    ];
    $form['delete_history_fieldset'] = [
      '#type' => 'details',
      '#title' => $this->t('Delete Limit for Password Changed History Table'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#open' => TRUE,
    ];
    $limit_arr = [1000, 2000, 3000, 4000, 5000];
    $limits = array_combine($limit_arr, $limit_arr);
    $form['delete_history_fieldset']['delete_records_limit'] = [
      '#title' => $this->t('Limit'),
      '#type' => 'select',
      '#default_value' => $config->get('delete_records_limit'),
      '#required' => TRUE,
      '#description' => $this->t('Select the Limit to Delete Records using Batch Operation in Delete History Page.'),
      '#options' => $limits,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('password_notification.settings');
    $config->set('password_notification_mail', $form_state->getValue('password_notification_mail'));
    $config->set('password_notification_log', $form_state->getValue('password_notification_log'));
    $config->set('mail_subject', $form_state->getValue('mail_subject'));
    $config->set('mail_body', $form_state->getValue('mail_body'));
    $config->set('mail_bcc', $form_state->getValue('mail_bcc'));
    $config->set('mail_cc', $form_state->getValue('mail_cc'));
    $config->set('delete_records_limit', $form_state->getValue('delete_records_limit'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

}
